#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2016-03-31
#
# WATO for plugin cisco_wlc_temp
#
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Tuple,
    Integer,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_cisco_wlc_temp():
    return Dictionary(elements=[
        ('levels_upper',
         Tuple(
             title=_('Temperature upper levels'),
             help=_('Set the upper levels for temperature in °C. From the MID description: '
                    'Operating Environment of the Airespace Switch. commercial is Commercial (0 to 40 C) '
                    'and industrial is Industrial (-10 to 70 C)'),
             elements=[
                 Integer(title=_('Warning at'), unit=u'°C', default_value=36, minvalue=-20, maxvalue=100),
                 Integer(title=_('Critical at'), unit=u'°C', default_value=38, minvalue=-20, maxvalue=100)
             ],
         ),
         ),
        ('levels_lower',
         Tuple(
             title=_('Temperature lower levels'),
             help=_('Set the lower levels for temperature in °C From the MID description: '
                    'Operating Environment of the Airespace Switch. commercial is Commercial (0 to 40 C) '
                    'and industrial is Industrial (-10 to 70 C)'),
             elements=[
                 Integer(title=_('Warning below'), unit=u'°C', default_value=12, minvalue=-20, maxvalue=100),
                 Integer(title=_('Critical below'), unit=u'°C', default_value=10, minvalue=-20, maxvalue=100)
             ],
         ),
         ),
    ])


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_wlc_temp',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_wlc_temp,
        title=lambda: _('Cisco WLC Temperature'),
    ))
